@@ -63,8 +63,6 @@ Last update: 2017-05-16
 *
 ***********************************************************************/
 
-#define PJ_LIB_
-
 #include <errno.h>
 #include <math.h>
 #include <string.h>
@@ -437,7 +435,7 @@ static double get_unit_conversion_factor(const char *name, int *p_is_linear,
 }
 
 /***********************************************************************/
-PJ *CONVERSION(unitconvert, 0) {
+PJ *PJ_CONVERSION(unitconvert, 0) {
     /***********************************************************************/
     struct pj_opaque_unitconvert *Q =
         static_cast<struct pj_opaque_unitconvert *>(
