@@ -287,7 +287,7 @@ util::PropertyMap createPropertiesForInverse(const CoordinateOperation *op,
                 }
             }
             if (!curToken.empty()) {
-                tokens.push_back(curToken);
+                tokens.push_back(std::move(curToken));
             }
             for (size_t i = tokens.size(); i > 0;) {
                 i--;
@@ -382,6 +382,7 @@ static std::set<std::string> buildSetEquivalentParameters() {
 
         {EPSG_NAME_PARAMETER_SCALE_FACTOR_AT_NATURAL_ORIGIN, WKT1_SCALE_FACTOR,
          EPSG_NAME_PARAMETER_SCALE_FACTOR_INITIAL_LINE,
+         EPSG_NAME_PARAMETER_SCALE_FACTOR_PROJECTION_CENTRE,
          EPSG_NAME_PARAMETER_SCALE_FACTOR_PSEUDO_STANDARD_PARALLEL, nullptr},
 
         {WKT1_LATITUDE_OF_ORIGIN, WKT1_LATITUDE_OF_CENTER,
@@ -396,6 +397,9 @@ static std::set<std::string> buildSetEquivalentParameters() {
          EPSG_NAME_PARAMETER_LONGITUDE_PROJECTION_CENTRE,
          EPSG_NAME_PARAMETER_LONGITUDE_OF_ORIGIN, nullptr},
 
+        {EPSG_NAME_PARAMETER_AZIMUTH_INITIAL_LINE,
+         EPSG_NAME_PARAMETER_AZIMUTH_PROJECTION_CENTRE, nullptr},
+
         {"pseudo_standard_parallel_1", WKT1_STANDARD_PARALLEL_1, nullptr},
     };
 
