@@ -37,6 +37,7 @@ PROJ_HEAD(crast, "Craster Parabolic (Putnins P4)")
 PROJ_HEAD(defmodel, "Deformation model")
 PROJ_HEAD(deformation, "Kinematic grid shift")
 PROJ_HEAD(denoy, "Denoyer Semi-Elliptical")
+PROJ_HEAD(airocean, "Airocean Fuller")
 PROJ_HEAD(eck1, "Eckert I")
 PROJ_HEAD(eck2, "Eckert II")
 PROJ_HEAD(eck3, "Eckert III")
@@ -153,6 +154,7 @@ PROJ_HEAD(set, "Set coordinate value")
 PROJ_HEAD(sinu, "Sinusoidal (Sanson-Flamsteed)")
 PROJ_HEAD(som, "Space Oblique Mercator")
 PROJ_HEAD(somerc, "Swiss. Obl. Mercator")
+PROJ_HEAD(spilhaus, "Spilhaus")
 PROJ_HEAD(stere, "Stereographic")
 PROJ_HEAD(sterea, "Oblique Stereographic Alternative")
 PROJ_HEAD(gstmerc,
