@@ -1,5 +1,3 @@
-#define PJ_LIB_
-
 #include <errno.h>
 #include <math.h>
 
@@ -7,7 +5,7 @@
 #include "proj_internal.h"
 
 namespace { // anonymous namespace
-struct pj_opaque {
+struct pj_cea_data {
     double qp;
     double *apa;
 };
@@ -19,7 +17,7 @@ PROJ_HEAD(cea, "Equal Area Cylindrical") "\n\tCyl, Sph&Ell\n\tlat_ts=";
 static PJ_XY cea_e_forward(PJ_LP lp, PJ *P) { /* Ellipsoidal, forward */
     PJ_XY xy = {0.0, 0.0};
     xy.x = P->k0 * lp.lam;
-    xy.y = 0.5 * pj_qsfn(sin(lp.phi), P->e, P->one_es) / P->k0;
+    xy.y = 0.5 * pj_authalic_lat_q(sin(lp.phi), P) / P->k0;
     return xy;
 }
 
@@ -32,9 +30,10 @@ static PJ_XY cea_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
 
 static PJ_LP cea_e_inverse(PJ_XY xy, PJ *P) { /* Ellipsoidal, inverse */
     PJ_LP lp = {0.0, 0.0};
-    lp.phi = pj_authlat(asin(2. * xy.y * P->k0 /
-                             static_cast<struct pj_opaque *>(P->opaque)->qp),
-                        static_cast<struct pj_opaque *>(P->opaque)->apa);
+    const struct pj_cea_data *Q =
+        static_cast<const struct pj_cea_data *>(P->opaque);
+    lp.phi = pj_authalic_lat_inverse(asin(2. * xy.y * P->k0 / Q->qp), Q->apa, P,
+                                     Q->qp);
     lp.lam = xy.x / P->k0;
     return lp;
 }
@@ -57,25 +56,25 @@ static PJ_LP cea_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
     return (lp);
 }
 
-static PJ *destructor(PJ *P, int errlev) { /* Destructor */
+static PJ *pj_cea_destructor(PJ *P, int errlev) { /* Destructor */
     if (nullptr == P)
         return nullptr;
 
     if (nullptr == P->opaque)
         return pj_default_destructor(P, errlev);
 
-    free(static_cast<struct pj_opaque *>(P->opaque)->apa);
+    free(static_cast<struct pj_cea_data *>(P->opaque)->apa);
     return pj_default_destructor(P, errlev);
 }
 
-PJ *PROJECTION(cea) {
+PJ *PJ_PROJECTION(cea) {
     double t = 0.0;
-    struct pj_opaque *Q =
-        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
+    struct pj_cea_data *Q = static_cast<struct pj_cea_data *>(
+        calloc(1, sizeof(struct pj_cea_data)));
     if (nullptr == Q)
         return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
-    P->destructor = destructor;
+    P->destructor = pj_cea_destructor;
 
     if (pj_param(P->ctx, P->params, "tlat_ts").i) {
         t = pj_param(P->ctx, P->params, "rlat_ts").f;
@@ -91,11 +90,11 @@ PJ *PROJECTION(cea) {
         t = sin(t);
         P->k0 /= sqrt(1. - P->es * t * t);
         P->e = sqrt(P->es);
-        Q->apa = pj_authset(P->es);
+        Q->apa = pj_authalic_lat_compute_coeffs(P->n);
         if (!(Q->apa))
             return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
 
-        Q->qp = pj_qsfn(1., P->e, P->one_es);
+        Q->qp = pj_authalic_lat_q(1.0, P);
         P->inv = cea_e_inverse;
         P->fwd = cea_e_forward;
     } else {
@@ -105,3 +104,5 @@ PJ *PROJECTION(cea) {
 
     return P;
 }
+
+#undef EPS
