@@ -1,4 +1,4 @@
-#define PJ_LIB_
+
 
 #include "proj.h"
 #include "proj_internal.h"
@@ -29,7 +29,7 @@ static PJ_XY lask_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
     return xy;
 }
 
-PJ *PROJECTION(lask) {
+PJ *PJ_PROJECTION(lask) {
 
     P->fwd = lask_s_forward;
     P->es = 0.;
